@@ -1,8 +1,11 @@
 import os
 import sys
+from importlib.metadata import version
 
 from django.conf import settings
 
+__version__ = version(__package__)
+
 
 def get_cgi_handler_code():
     template = """#!{}
@@ -12,7 +15,6 @@ from {} import {}
 
 wsgiref.handlers.CGIHandler().run(application)
 """
-    os.system("""osascript -e 'tell application "Terminal"' -e 'activate' -e 'end tell'""");import pudb; pu.db
     python = os.path.join(sys.prefix, 'bin', 'python')
     split = settings.WSGI_APPLICATION.split('.')
     module = '.'.join(split[:-1])
