@@ -1,3 +1,5 @@
+import os
+
 from django.core.management.base import BaseCommand
 
 from django_cgi import get_cgi_handler_code
@@ -8,5 +10,7 @@ class Command(BaseCommand):
     requires_system_checks = False
 
     def handle(self, *args, **options):
-        with open('cgi_handler.py', 'w') as f:
+        path = 'cgi_handler.py'
+        with open(path, 'w') as f:
             f.write(get_cgi_handler_code())
+        os.chmod(path, 0o755)
